@@ -1071,6 +1071,35 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyInstancePre(self, request):
+        """This API is used to change the configurations of a prepaid instance, such as disk capacity and bandwidth.
+
+        :param request: Request instance for ModifyInstancePre.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.ModifyInstancePreRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.ModifyInstancePreResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyInstancePre", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyInstancePreResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyPassword(self, request):
         """This API is used to change the password.
 
