@@ -38,7 +38,8 @@ class EcdnClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AddEcdnDomain", params)
+            headers = request.headers
+            body = self.call("AddEcdnDomain", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AddEcdnDomainResponse()
@@ -68,7 +69,8 @@ class EcdnClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteEcdnDomain", params)
+            headers = request.headers
+            body = self.call("DeleteEcdnDomain", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteEcdnDomainResponse()
@@ -98,7 +100,8 @@ class EcdnClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDomains", params)
+            headers = request.headers
+            body = self.call("DescribeDomains", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDomainsResponse()
@@ -128,7 +131,8 @@ class EcdnClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDomainsConfig", params)
+            headers = request.headers
+            body = self.call("DescribeDomainsConfig", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDomainsConfigResponse()
@@ -156,7 +160,8 @@ class EcdnClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeEcdnDomainLogs", params)
+            headers = request.headers
+            body = self.call("DescribeEcdnDomainLogs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeEcdnDomainLogsResponse()
@@ -184,7 +189,8 @@ class EcdnClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeEcdnDomainStatistics", params)
+            headers = request.headers
+            body = self.call("DescribeEcdnDomainStatistics", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeEcdnDomainStatisticsResponse()
@@ -220,7 +226,8 @@ class EcdnClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeEcdnStatistics", params)
+            headers = request.headers
+            body = self.call("DescribeEcdnStatistics", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeEcdnStatisticsResponse()
@@ -250,7 +257,8 @@ class EcdnClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeIpStatus", params)
+            headers = request.headers
+            body = self.call("DescribeIpStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeIpStatusResponse()
@@ -280,7 +288,8 @@ class EcdnClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribePurgeQuota", params)
+            headers = request.headers
+            body = self.call("DescribePurgeQuota", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribePurgeQuotaResponse()
@@ -310,7 +319,8 @@ class EcdnClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribePurgeTasks", params)
+            headers = request.headers
+            body = self.call("DescribePurgeTasks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribePurgeTasksResponse()
@@ -340,7 +350,8 @@ class EcdnClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PurgePathCache", params)
+            headers = request.headers
+            body = self.call("PurgePathCache", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PurgePathCacheResponse()
@@ -370,7 +381,8 @@ class EcdnClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PurgeUrlsCache", params)
+            headers = request.headers
+            body = self.call("PurgeUrlsCache", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PurgeUrlsCacheResponse()
@@ -400,7 +412,8 @@ class EcdnClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("StartEcdnDomain", params)
+            headers = request.headers
+            body = self.call("StartEcdnDomain", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.StartEcdnDomainResponse()
@@ -430,7 +443,8 @@ class EcdnClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("StopEcdnDomain", params)
+            headers = request.headers
+            body = self.call("StopEcdnDomain", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.StopEcdnDomainResponse()
@@ -461,7 +475,8 @@ class EcdnClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateDomainConfig", params)
+            headers = request.headers
+            body = self.call("UpdateDomainConfig", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateDomainConfigResponse()
