@@ -14,6 +14,12 @@
 # limitations under the License.
 
 
+# Authentication failed.
+AUTHFAILURE_INVALIDAUTHORIZATION = 'AuthFailure.InvalidAuthorization'
+
+# Operation failed.
+FAILEDOPERATION = 'FailedOperation'
+
 # This operation cannot be performed across algorithm model versions.
 FAILEDOPERATION_ACROSSVERSIONSERROR = 'FailedOperation.AcrossVersionsError'
 
