@@ -35,6 +35,9 @@ INVALIDPARAMETER_ATTACHEDINPUTS = 'InvalidParameter.AttachedInputs'
 # Incorrect audio transcoding template.
 INVALIDPARAMETER_AUDIOTEMPLATES = 'InvalidParameter.AudioTemplates'
 
+# Channel ID error.
+INVALIDPARAMETER_CHANNELID = 'InvalidParameter.ChannelId'
+
 # Invalid `EndTime`.
 INVALIDPARAMETER_ENDTIME = 'InvalidParameter.EndTime'
 
@@ -59,6 +62,9 @@ INVALIDPARAMETER_NOTFOUND = 'InvalidParameter.NotFound'
 # Invalid `OutputGroups`.
 INVALIDPARAMETER_OUTPUTGROUPS = 'InvalidParameter.OutputGroups'
 
+# Page number error.
+INVALIDPARAMETER_PAGENUM = 'InvalidParameter.PageNum'
+
 # Invalid `Plan` parameter
 INVALIDPARAMETER_PLAN = 'InvalidParameter.Plan'
 
