@@ -39,7 +39,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AddSmsSign", params)
+            headers = request.headers
+            body = self.call("AddSmsSign", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AddSmsSignResponse()
@@ -70,7 +71,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AddSmsTemplate", params)
+            headers = request.headers
+            body = self.call("AddSmsTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AddSmsTemplateResponse()
@@ -100,7 +102,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CallbackStatusStatistics", params)
+            headers = request.headers
+            body = self.call("CallbackStatusStatistics", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CallbackStatusStatisticsResponse()
@@ -130,7 +133,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteSmsSign", params)
+            headers = request.headers
+            body = self.call("DeleteSmsSign", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteSmsSignResponse()
@@ -160,7 +164,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteSmsTemplate", params)
+            headers = request.headers
+            body = self.call("DeleteSmsTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteSmsTemplateResponse()
@@ -189,7 +194,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribePhoneNumberInfo", params)
+            headers = request.headers
+            body = self.call("DescribePhoneNumberInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribePhoneNumberInfoResponse()
@@ -219,7 +225,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSmsSignList", params)
+            headers = request.headers
+            body = self.call("DescribeSmsSignList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSmsSignListResponse()
@@ -249,7 +256,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSmsTemplateList", params)
+            headers = request.headers
+            body = self.call("DescribeSmsTemplateList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSmsTemplateListResponse()
@@ -281,7 +289,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifySmsSign", params)
+            headers = request.headers
+            body = self.call("ModifySmsSign", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifySmsSignResponse()
@@ -313,7 +322,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifySmsTemplate", params)
+            headers = request.headers
+            body = self.call("ModifySmsTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifySmsTemplateResponse()
@@ -345,7 +355,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PullSmsReplyStatus", params)
+            headers = request.headers
+            body = self.call("PullSmsReplyStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PullSmsReplyStatusResponse()
@@ -376,7 +387,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PullSmsReplyStatusByPhoneNumber", params)
+            headers = request.headers
+            body = self.call("PullSmsReplyStatusByPhoneNumber", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PullSmsReplyStatusByPhoneNumberResponse()
@@ -408,7 +420,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PullSmsSendStatus", params)
+            headers = request.headers
+            body = self.call("PullSmsSendStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PullSmsSendStatusResponse()
@@ -439,7 +452,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PullSmsSendStatusByPhoneNumber", params)
+            headers = request.headers
+            body = self.call("PullSmsSendStatusByPhoneNumber", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PullSmsSendStatusByPhoneNumberResponse()
@@ -470,7 +484,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SendSms", params)
+            headers = request.headers
+            body = self.call("SendSms", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SendSmsResponse()
@@ -500,7 +515,8 @@ class SmsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SendStatusStatistics", params)
+            headers = request.headers
+            body = self.call("SendStatusStatistics", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SendStatusStatisticsResponse()
