@@ -84,6 +84,35 @@ class StsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def AssumeRoleWithWebIdentity(self, request):
+        """This API is used to apply for an OIDC role credential.
+
+        :param request: Request instance for AssumeRoleWithWebIdentity.
+        :type request: :class:`tencentcloud.sts.v20180813.models.AssumeRoleWithWebIdentityRequest`
+        :rtype: :class:`tencentcloud.sts.v20180813.models.AssumeRoleWithWebIdentityResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("AssumeRoleWithWebIdentity", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.AssumeRoleWithWebIdentityResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def GetCallerIdentity(self, request):
         """This API is used to get the identity information of the current caller.
         The persistent keys of the root account and sub-account as well as the temporary credentials generated by `AssumeRole` and `GetFederationToken` can be used to get the identity information.
